Constant Field Values
Contents
software.amazon.*
-
software.amazon.awssdk.services.outposts.OutpostsAsyncClient Modifier and Type Constant Field Value public static final StringSERVICE_METADATA_ID"outposts"public static final StringSERVICE_NAME"outposts" -
software.amazon.awssdk.services.outposts.OutpostsClient Modifier and Type Constant Field Value public static final StringSERVICE_METADATA_ID"outposts"public static final StringSERVICE_NAME"outposts"
-
software.amazon.awssdk.services.outposts.internal.ServiceVersionInfo Modifier and Type Constant Field Value public static final StringVERSION"2.41.x"