Class StartCapacityTaskRequest

    • Method Detail

      • outpostIdentifier

        public final String outpostIdentifier()

        The ID or ARN of the Outposts associated with the specified capacity task.

        Returns:
        The ID or ARN of the Outposts associated with the specified capacity task.
      • orderId

        public final String orderId()

        The ID of the Amazon Web Services Outposts order associated with the specified capacity task.

        Returns:
        The ID of the Amazon Web Services Outposts order associated with the specified capacity task.
      • hasInstancePools

        public final boolean hasInstancePools()
        For responses, this returns true if the service returned a value for the InstancePools property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • instancePools

        public final List<InstanceTypeCapacity> instancePools()

        The instance pools specified in the capacity task.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasInstancePools() method.

        Returns:
        The instance pools specified in the capacity task.
      • instancesToExclude

        public final InstancesToExclude instancesToExclude()

        List of user-specified running instances that must not be stopped in order to free up the capacity needed to run the capacity task.

        Returns:
        List of user-specified running instances that must not be stopped in order to free up the capacity needed to run the capacity task.
      • dryRun

        public final Boolean dryRun()

        You can request a dry run to determine if the instance type and instance size changes is above or below available instance capacity. Requesting a dry run does not make any changes to your plan.

        Returns:
        You can request a dry run to determine if the instance type and instance size changes is above or below available instance capacity. Requesting a dry run does not make any changes to your plan.
      • taskActionOnBlockingInstances

        public final TaskActionOnBlockingInstances taskActionOnBlockingInstances()

        Specify one of the following options in case an instance is blocking the capacity task from running.

        • WAIT_FOR_EVACUATION - Checks every 10 minutes over 48 hours to determine if instances have stopped and capacity is available to complete the task.

        • FAIL_TASK - The capacity task fails.

        If the service returns an enum value that is not available in the current SDK version, taskActionOnBlockingInstances will return TaskActionOnBlockingInstances.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from taskActionOnBlockingInstancesAsString().

        Returns:
        Specify one of the following options in case an instance is blocking the capacity task from running.

        • WAIT_FOR_EVACUATION - Checks every 10 minutes over 48 hours to determine if instances have stopped and capacity is available to complete the task.

        • FAIL_TASK - The capacity task fails.

        See Also:
        TaskActionOnBlockingInstances
      • taskActionOnBlockingInstancesAsString

        public final String taskActionOnBlockingInstancesAsString()

        Specify one of the following options in case an instance is blocking the capacity task from running.

        • WAIT_FOR_EVACUATION - Checks every 10 minutes over 48 hours to determine if instances have stopped and capacity is available to complete the task.

        • FAIL_TASK - The capacity task fails.

        If the service returns an enum value that is not available in the current SDK version, taskActionOnBlockingInstances will return TaskActionOnBlockingInstances.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from taskActionOnBlockingInstancesAsString().

        Returns:
        Specify one of the following options in case an instance is blocking the capacity task from running.

        • WAIT_FOR_EVACUATION - Checks every 10 minutes over 48 hours to determine if instances have stopped and capacity is available to complete the task.

        • FAIL_TASK - The capacity task fails.

        See Also:
        TaskActionOnBlockingInstances
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object